@@ -342,6 +342,8 @@ class AppHandler(object):
         # otherwise caller-supplied default is assumed
         spec = self.config.get('rattail.batch', '{}.handler'.format(key),
                                default=default)
+        if not spec:
+            spec = self.config.get('rattail.batch', '{}.handler.default'.format(key))
 
         # TODO: this probably should go away?
         # if none of the above gave us a spec, check for common 'importer' type
@@ -702,6 +704,20 @@ class AppHandler(object):
             self.people_handler = factory(self.config, **kwargs)
         return self.people_handler
 
+    def get_poser_handler(self, **kwargs):
+        """
+        Get the configured "poser" handler.
+
+        :returns: The :class:`~rattail.poser.PoserHandler` instance
+           for the app.
+        """
+        if not hasattr(self, 'poser_handler'):
+            spec = self.config.get('rattail', 'poser.handler',
+                                   default='rattail.poser:PoserHandler')
+            factory = self.load_object(spec)
+            self.poser_handler = factory(self.config, **kwargs)
+        return self.poser_handler
+
     def get_products_handler(self, **kwargs):
         """
         Get the configured "products" handler.
@@ -848,6 +864,17 @@ class AppHandler(object):
             if not os.path.exists(path):
                 os.mkdir(path)
 
+    def render_mako_template(self, template_path, context,
+                             output_path=None, **kwargs):
+        """
+        Convenience method to render any (specified) Mako template.
+        """
+        output = Template(filename=template_path).render(**context)
+        if output_path:
+            with open(output_path, 'wt') as f:
+                f.write(output)
+        return output
+
     def make_config_file(self, file_type, output_path, template_path=None,
                          **kwargs):
         """
@@ -903,10 +930,8 @@ class AppHandler(object):
             'pyramid_port': 9080,
         }
         context.update(kwargs)
-        config = Template(filename=template_path).render(**context)
-        with open(output_path, 'wt') as f:
-            f.write(config)
-
+        self.render_mako_template(template_path, context,
+                                  output_path=output_path)
         return output_path
 
     def find_config_template(self, name):
