@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -204,6 +204,7 @@ Usage: {0.name} [options] <command> [command-options]
 Options:
   -c PATH, --config=PATH
                     Config path (may be specified more than once)
+  -n, --no-init     Do not read any config files
   -P, --progress    Show progress indicators (where relevant)
   -R, --runas       Optional username to impersonate when running command
   -V, --version     Display program version and exit
@@ -852,24 +853,21 @@ class MakeAppDir(Subcommand):
             app_path = os.path.join(sys.prefix, 'app')
         app_path = app_path.rstrip('/')
 
-        if not os.path.exists(app_path):
-            os.mkdir(app_path)
+        self.app.make_appdir(app_path)
 
+        # TODO: this bit should probably be part of app method
         if args.user:
             import pwd
             pwdata = pwd.getpwnam(args.user)
-        folders = [
-            'data',
-            os.path.join('data', 'uploads'),
-            'log',
-            'sessions',
-            'work',
-        ]
-        for name in folders:
-            path = os.path.join(app_path, name)
-            if not os.path.exists(path):
-                os.mkdir(path)
-            if args.user:
+            folders = [
+                'data',
+                os.path.join('data', 'uploads'),
+                'log',
+                'sessions',
+                'work',
+            ]
+            for name in folders:
+                path = os.path.join(app_path, name)
                 os.chown(path, pwdata.pw_uid, pwdata.pw_gid)
 
         self.stdout.write("Rattail app dir generated at: {}\n".format(app_path))
@@ -892,28 +890,16 @@ class MakeConfig(Subcommand):
                             "case the filename is inferred from 'type'.  Default is to current "
                             "working folder.")
 
-    def find_template(self, name):
-        from rattail.files import resource_path
-
-        template_paths = self.config.getlist('rattail.config', 'templates',
-                                             default=['rattail:data/config'])
-        for template_path in template_paths:
-            path = resource_path('{}/{}.conf'.format(template_path.rstrip('/'), name))
-            if os.path.exists(path):
-                return path
-
     def run(self, args):
-        template_path = self.find_template(args.type)
+        template_path = self.app.find_config_template(args.type)
         if not template_path:
             self.stderr.write("config template not found for type: {}\n".format(args.type))
             sys.exit(1)
 
         output_path = os.path.abspath(args.output)
-        if os.path.isdir(output_path):
-            output_path = os.path.join(output_path, os.path.basename(template_path))
-
-        shutil.copy(template_path, output_path)
-        self.stdout.write("Config file generated at: {}\n".format(output_path))
+        config_path = self.app.make_config_file(args.type, output_path,
+                                                template_path=template_path)
+        self.stdout.write("Config file generated at: {}\n".format(config_path))
 
 
 class MakeUser(Subcommand):
