@@ -62,7 +62,7 @@ def record_changes(session, recorder=None, config=None):
     if isinstance(recorder, ChangeRecorder):
         pass
     elif callable(recorder):
-        recorder = recorder()
+        recorder = recorder(config)
     elif recorder is None:
         if config:
             spec = config.get('rattail.db', 'changes.recorder', usedb=False)
@@ -110,7 +110,8 @@ class ChangeRecorder(object):
 
     def __init__(self, config):
         self.config = config
-        self.model = config.get_model()
+        if self.config:
+            self.model = config.get_model()
 
     def __call__(self, session, flush_context, instances):
         """
