@@ -26,6 +26,7 @@ Common email config objects
 
 from __future__ import unicode_literals, absolute_import
 
+import datetime
 import sys
 import socket
 from traceback import format_exception
@@ -316,6 +317,32 @@ class rattail_problems_stale_inventory_batch(ProblemReportEmail):
         }
 
 
+class CommandOutputEmail(Email):
+    """
+    Base class for command output emails.
+    """
+    abstract = True
+    fallback_key = 'run_n_mail'
+
+    def sample_data(self, request):
+        runtime = datetime.timedelta(seconds=300)
+        return {
+            'cmd': ['/bin/sleep', '1'],
+            'runtime': runtime,
+            'runtime_pretty': self.app.render_duration(seconds=runtime.seconds),
+            'retcode': 0,
+            'output': '(output goes here)',
+        }
+
+
+class run_n_mail(CommandOutputEmail):
+    """
+    Emails output of an arbitrary command.
+    """
+    abstract = False
+    fallback_key = None
+
+
 class upgrade_failure(Email):
     """
     Sent when an app upgrade is attempted, but ultimately failed.
