@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -46,7 +46,7 @@ class BulkToPostgreSQL(BulkImporter, ToSQLAlchemy):
 
     @property
     def data_path(self):
-        return os.path.join(self.config.workdir(require=True),
+        return os.path.join(self.config.workdir(),
                             'import_bulk_postgresql_{}.csv'.format(self.model_name))
 
     def setup(self):
@@ -63,7 +63,7 @@ class BulkToPostgreSQL(BulkImporter, ToSQLAlchemy):
 
     def prep_data_for_postgres(self, data):
         data = dict(data)
-        for key, value in data.iteritems():
+        for key, value in data.items():
             data[key] = self.prep_value_for_postgres(value)
         return data
 
@@ -77,7 +77,7 @@ class BulkToPostgreSQL(BulkImporter, ToSQLAlchemy):
 
         if isinstance(value, datetime.datetime):
             value = make_utc(value, tzinfo=False)
-        elif isinstance(value, basestring):
+        elif isinstance(value, six.string_types):
             value = value.replace('\\', '\\\\')
             value = value.replace('\r', '\\r')
             value = value.replace('\n', '\\n')
