@@ -309,13 +309,13 @@ class ProductsHandler(GenericHandler):
         ])
         if kwargs.get('lookup_vendor_code'): # pragma: no cover
             warnings.warn("`lookup_vendor_code` param is deprecated, "
-                          "please includle 'vendor_code' in `lookup_fields` "
+                          "please include 'vendor_code' in `lookup_fields` "
                           "instead", DeprecationWarning)
             if 'vendor_code' not in lookup_fields:
                 lookup_fields.append('vendor_code')
         if kwargs.get('lookup_by_code'): # pragma: no cover
             warnings.warn("`lookup_by_code` param is deprecated, "
-                          "please includle 'alt_code' in `lookup_fields` "
+                          "please include 'alt_code' in `lookup_fields` "
                           "instead", DeprecationWarning)
             if 'alt_code' not in lookup_fields:
                 lookup_fields.append('alt_code')
@@ -790,6 +790,8 @@ class ProductsHandler(GenericHandler):
         :returns: String containing the rendered price, or ``None`` if
            nothing was applicable.
         """
+        if not price:
+            return ""
         if price.price is not None and price.pack_price is not None:
             if price.multiple > 1:
                 return "{} / {}  ({} / {})".format(
